class Product < ActiveRecord::Base
  set_table_name 'producten'
  belongs_to :soort
  belongs_to :uitgeverij
  has_many :orderlijns
  
  validates_presence_of :titel, :auteurs, :afbeelding_url, :prijs, :soort_id
  validates_numericality_of :prijs, :soort_id
  validates_uniqueness_of :titel
  validates_format_of :afbeelding_url,
                             :with => %r(\.(gif|jpg|jpeg|png)$)i,
                             :message => 'moet een GIF,	JPG of PNG afbeelding zijn (eindigen op .gif of .jpg of .jpeg of .png)'
  validates_length_of :titel, :minimum=>5, :message=>'moet langer dan %d karakters zijn'
  validate :prijs_moet_positief_zijn
    
  def prijs_moet_positief_zijn
    errors.add(:prijs, 'moet positief zijn!') if prijs < 0
  end

  def self.find_producten_voor_verkoop
      find(:all, :order => 'titel')
  end
  
end
